@@ -23,8 +23,10 @@ import random
 import threading
 import platform
 import os
+from feature_detect import FeatureDetection
 
-class RiakTransport(object):
+
+class RiakTransport(FeatureDetection):
     """
     Class to encapsulate transport details
     """
@@ -60,14 +62,14 @@ class RiakTransport(object):
         """
         raise RiakError("not implemented")
 
-    def get(self, robj, r = None, vtag = None):
+    def get(self, robj, r=None, vtag=None):
         """
         Serialize get request and deserialize response
         @return (vclock=None, [(metadata, value)]=None)
         """
         raise RiakError("not implemented")
 
-    def put(self, robj, w = None, dw = None, return_body = True):
+    def put(self, robj, w=None, dw=None, return_body=True):
         """
         Serialize put request and deserialize response - if 'content'
         is true, retrieve the updated metadata/content
@@ -85,28 +87,28 @@ class RiakTransport(object):
         """
         raise RiakError("not implemented")
 
-    def delete(self, robj, rw = None):
+    def delete(self, robj, rw=None):
         """
         Serialize delete request and deserialize response
         @return true
         """
         raise RiakError("not implemented")
 
-    def get_buckets(self) :
+    def get_buckets(self):
         """
         Serialize get buckets request and deserialize response
         @return dict()
         """
         raise RiakError("not implemented")
 
-    def get_bucket_props(self, bucket) :
+    def get_bucket_props(self, bucket):
         """
         Serialize get bucket property request and deserialize response
         @return dict()
         """
         raise RiakError("not implemented")
 
-    def set_bucket_props(self, bucket, props) :
+    def set_bucket_props(self, bucket, props):
         """
         Serialize set bucket property request and deserialize response
         bucket = bucket object
@@ -115,7 +117,7 @@ class RiakTransport(object):
         """
         raise RiakError("not implemented")
 
-    def mapred(self, inputs, query, timeout = None) :
+    def mapred(self, inputs, query, timeout=None):
         """
         Serialize map/reduce request
         """
@@ -123,8 +125,9 @@ class RiakTransport(object):
 
     def set_client_id(self, client_id):
         """
-        Set the client id. This overrides the default, random client id, which is automatically
-        generated when none is specified in when creating the transport object.
+        Set the client id. This overrides the default, random client
+        id, which is automatically generated when none is specified in
+        when creating the transport object.
         """
         raise RiakError("not implemented")
 
@@ -134,7 +137,70 @@ class RiakTransport(object):
         """
         raise RiakError("not implemented")
 
-    def store_file(self, key, content_type="application/octet-stream", content=None):
+    def search(self, index, query, **params):
+        """
+        Performs a search query.
+        """
+        raise RiakError("not implemented")
+
+    def get_index(self, bucket, index, startkey, endkey=None):
+        """
+        Performs a secondary index query.
+        """
+        raise RiakError("not implemented")
+
+    def _search_mapred_emu(self, index, query):
+        """
+        Emulates a search request via MapReduce. Used in the case
+        where the transport supports MapReduce but has no native
+        search capability.
+        """
+        phases = []
+        if not self.phaseless_mapred():
+            phases.append({'language': 'erlang',
+                          'module': 'riak_kv_mapreduce',
+                          'function': 'reduce_identity',
+                          'keep': True})
+        mr_result = self.mapred({'module': 'riak_search',
+                                 'function': 'mapred_search',
+                                 'arg': [index, query]},
+                           phases)
+        result = {'num_found': len(mr_result),
+                  'max_score': 0.0,
+                  'docs': []}
+        for bucket, key, data in mr_result:
+            if u'score' in data and data[u'score'][0] > result['max_score']:
+                result['max_score'] = data[u'score'][0]
+            result['docs'].append({u'id': key})
+        return result
+
+    def _get_index_mapred_emu(self, bucket, index, startkey, endkey=None):
+        """
+        Emulates a secondary index request via MapReduce. Used in the
+        case where the transport supports MapReduce but has no native
+        secondary index query capability.
+        """
+        phases = []
+        if not self.phaseless_mapred():
+            phases.append({'language': 'erlang',
+                           'module': 'riak_kv_mapreduce',
+                           'function': 'reduce_identity',
+                           'keep': True})
+        if endkey:
+            result = self.mapred({'bucket': bucket,
+                                  'index': index,
+                                  'start': startkey,
+                                  'end': endkey},
+                                 phases)
+        else:
+            result = self.mapred({'bucket': bucket,
+                                  'index': index,
+                                  'key': startkey},
+                                 phases)
+        return [key for bucket, key in result]
+
+    def store_file(self, key, content_type="application/octet-stream",
+                   content=None):
         """
         Store a large piece of data in luwak.
         key = the key/filename for the object
